Enum medea_client_api_proto::Event [−][src]
WebSocket message from Medea to Jason.
Variants
Media Server notifies Client that he joined Room.
Fields of RoomJoined
member_id: MemberIdID of Member which joined Room.
Media Server notifies Client that he left Room.
Fields of RoomLeft
close_reason: CloseReasonCloseReason with which Client was left.
Media Server notifies Web Client about necessity of RTCPeerConnection creation.
Fields of PeerCreated
Media Server notifies Web Client about necessity to apply specified SDP Answer to Web Client’s RTCPeerConnection.
Media Server notifies Web Client that his SDP offer was applied.
Media Server notifies Web Client about necessity to apply specified ICE Candidate.
Fields of IceCandidateDiscovered
peer_id: PeerIdcandidate: IceCandidateMedia Server notifies Web Client about necessity of RTCPeerConnection close.
Media Server notifies about necessity to update Tracks in specified
Peer.
Fields of PeerUpdated
peer_id: PeerIdupdates: Vec<PeerUpdate>List of PeerUpdates which should be applied.
negotiation_role: Option<NegotiationRole>Negotiation role basing on which should be sent
Command::MakeSdpOffer or Command::MakeSdpAnswer.
If None then no (re)negotiation should be done.
Media Server notifies about connection quality score update.
Fields of ConnectionQualityUpdated
partner_member_id: MemberIdPartner MemberId of the Peer.
quality_score: ConnectionQualityScoreEstimated connection quality.
Media Server synchronizes Web Client about State synchronization.
Fields of StateSynchronized
state: RoomImplementations
impl Event[src]
pub async fn dispatch_with<T: EventHandler>(
self,
handler: &T
) -> <T as EventHandler>::Output[src]
self,
handler: &T
) -> <T as EventHandler>::Output
Dispatches Event with given EventHandler.