pub enum PeerConnectionState {
New,
Connecting,
Connected,
Disconnected,
Failed,
Closed,
}Expand description
PeerConnection’s connection state.
Variants
New
At least one of the connection’s ICE transports are in the
IceConnectionState::New state, and none of them are in one
of the following states: IceConnectionState::Checking,
IceConnectionState::Failed, or
IceConnectionState::Disconnected, or all of the connection’s
transports are in the IceConnectionState::Closed state.
Connecting
One or more of the ICE transports are currently in the process of
establishing a connection; that is, their IceConnectionState is
either IceConnectionState::Checking or
IceConnectionState::Connected, and no transports are in the
IceConnectionState::Failed state.
Connected
Every ICE transport used by the connection is either in use (state
IceConnectionState::Connected or IceConnectionState::Completed)
or is closed (IceConnectionState::Closed); in addition,
at least one transport is either IceConnectionState::Connected or
IceConnectionState::Completed.
Disconnected
At least one of the ICE transports for the connection is in the
IceConnectionState::Disconnected state and none of the other
transports are in the state IceConnectionState::Failed or
IceConnectionState::Checking.
Failed
One or more of the ICE transports on the connection is in the
IceConnectionState::Failed state.
Closed
The PeerConnection is closed.