Enum medea_client_api_proto::PeerUpdate [−][src]
Track update which should be applied to the Peer.
Variants
Added(Track)New Track should be added to the Peer.
Removed(TrackId)Track with the provided TrackId should be removed from the
Peer.
Can only refer Tracks already known to the Peer.
Updated(TrackPatchEvent)Track should be updated by this TrackPatchEvent in the Peer.
Can only refer tracks already known to the Peer.
Peer should start ICE restart process on the next renegotiation.